==> redux-1.0.15.tgz: package/lib/immutable/tests/selectors.test.js <==
"use strict";

var _immutable = require("immutable");

var _reducer = require("../reducer");

var _selectors = require("../selectors");

describe('selectBsRedux immutable', function () {
  var state;
  var bsReduxState;
  beforeEach(function () {
    bsReduxState = _reducer.initialState;
    state = (0, _immutable.fromJS)({
      'bs.redux': bsReduxState
    });
  });
  describe('selectBsRedux', function () {
    it('should select the @bootstrap-styled/redux state', function () {
      expect((0, _selectors.selectBsRedux)(state)).toEqual(state.get('bs.redux'));
    });
    describe('selectTheme', function () {
      it('should select the theme', function () {
        expect((0, _selectors.selectTheme)(state)).toEqual(bsReduxState.get('theme'));
      });
    });
    describe('selectThemes', function () {
      it('should select the themes', function () {
        expect((0, _selectors.selectThemes)(state)).toEqual(bsReduxState.get('themes'));
      });
    });
    describe('selectValue', function () {
      it('should select the value', function () {
        expect((0, _selectors.selectValue)(state)).toEqual(bsReduxState.getIn(['theme', '_name'])); // eslint-disable-line no-underscore-dangle
      });
    });
    describe('selectValues', function () {
      it('should select the values', function () {
        expect((0, _selectors.selectValues)(state)).toEqual(bsReduxState.get('themes').keySeq().toArray().map(function (t) {
          return t._name;
        })); // eslint-disable-line no-underscore-dangle
      });
    });
  });
});

==> redux-1.1.1.tgz: package/lib/immutable/tests/selectors.test.js <==
"use strict";

var _immutable = require("immutable");

var _reducer = require("../reducer");

var _selectors = require("../selectors");

var _constants = require("../../constants");

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

describe('selectBsRedux immutable', function () {
  var state;
  var bsReduxState;
  beforeEach(function () {
    bsReduxState = _reducer.initialState;
    state = (0, _immutable.fromJS)(_defineProperty({}, _constants.REDUX_BS_KEY, bsReduxState));
  });
  describe('selectBsRedux', function () {
    it('should select the @bootstrap-styled/redux state', function () {
      expect((0, _selectors.selectBsRedux)(state)).toEqual(state.get(_constants.REDUX_BS_KEY));
    });
    describe('selectTheme', function () {
      it('should select the theme', function () {
        expect((0, _selectors.selectTheme)(state)).toEqual(bsReduxState.get('theme'));
      });
    });
    describe('selectThemes', function () {
      it('should select the themes', function () {
        expect((0, _selectors.selectThemes)(state)).toEqual(bsReduxState.get('themes'));
      });
    });
    describe('selectValue', function () {
      it('should select the value', function () {
        expect((0, _selectors.selectValue)(state)).toEqual(bsReduxState.getIn(['theme', '_name'])); // eslint-disable-line no-underscore-dangle
      });
    });
    describe('selectValues', function () {
      it('should select the values', function () {
        expect((0, _selectors.selectValues)(state)).toEqual(bsReduxState.get('themes').keySeq().toArray().map(function (t) {
          return t._name;
        })); // eslint-disable-line no-underscore-dangle
      });
    });
  });
});
